@@ -31,6 +31,7 @@ For more information on usage visit https://github.com/Damgaard/PyImgur
 
 
 from base64 import b64encode
+from urlparse import urlparse
 import os.path
 import re
 import sys
@@ -39,10 +40,10 @@ import requests
 
 from pyimgur import request
 
-__version__ = '0.5.2'
+__version__ = '0.5.3'
 
 AUTHORIZE_URL = ("https://api.imgur.com/oauth2/authorize?"
-                 "client_id=%s&response_type=%s&state=%s")
+                 "client_id={}&response_type={}&state={}")
 EXCHANGE_URL = "https://api.imgur.com/oauth2/token"
 REFRESH_URL = "https://api.imgur.com/oauth2/token"
 
@@ -66,8 +67,8 @@ class Basic_object(object):
         if not self._has_fetched:
             self.refresh()
             return getattr(self, attribute)
-        raise AttributeError("%s instance has no attribute '%s'" %
-                             (type(self).__name__, attribute))
+        raise AttributeError("{0} instance has no attribute '{1}'".format(
+                             (type(self).__name__, attribute)))
 
     def __init__(self, json_dict, imgur, has_fetched=True):
         self._has_fetched = has_fetched
@@ -75,7 +76,7 @@ class Basic_object(object):
         self._populate(json_dict)
 
     def __repr__(self):
-        return "<%s %s>" % (type(self).__name__, self.id)
+        return "<{0} {1}>".format(type(self).__name__, self.id)
 
     @property
     def _delete_or_id_hash(self):
@@ -149,8 +150,8 @@ class Basic_object(object):
                 self.is_deleted = self.deleted
                 del self.deleted
             if "image_id" in vars(self):
-                self.permalink = ("http://imgur.com/gallery/%s/comment/%d" %
-                                 (self.image_id, self.id))
+                self.permalink = ("http://imgur.com/gallery/{0}/comment/"
+                                  "{1}".format(self.image_id, self.id))
                 self.image = Image({'id': self.image_id}, self._imgur,
                                    has_fetched=False)
                 del self.image_id
@@ -247,7 +248,8 @@ class Album(Basic_object):
     :ivar views: Total number of views the album has received.
     """
     def __init__(self, json_dict, imgur, has_fetched=True):
-        self._INFO_URL = ("https://api.imgur.com/3/album/%s" % json_dict['id'])
+        self._INFO_URL = ("https://api.imgur.com/3/album/"
+                          "{0}".format(json_dict['id']))
         self.deletehash = None
         super(Album, self).__init__(json_dict, imgur, has_fetched)
 
@@ -260,14 +262,15 @@ class Album(Basic_object):
             cannot add (non-existing or not owned by you) will not cause
             exceptions, but fail silently.
         """
-        url = "https://api.imgur.com/3/album/%s/add" % self.id
+        url = "https://api.imgur.com/3/album/{0}/add".format(self.id)
         params = {'ids': images}
         return self._imgur._send_request(url, needs_auth=True, params=params,
                                          method="POST")
 
     def delete(self):
         """Delete this album."""
-        url = "https://api.imgur.com/3/album/%s" % self._delete_or_id_hash
+        url = ("https://api.imgur.com/3/album/"
+               "{0}".format(self._delete_or_id_hash))
         return self._imgur._send_request(url, method="DELETE")
 
     def favorite(self):
@@ -276,7 +279,7 @@ class Album(Basic_object):
 
         Favoriting an already favorited album will unfavor it.
         """
-        url = "https://api.imgur.com/3/album/%s/favorite" % self.id
+        url = "https://api.imgur.com/3/album/{0}/favorite".format(self.id)
         return self._imgur._send_request(url, needs_auth=True, method="POST")
 
     def remove_images(self, images):
@@ -288,8 +291,8 @@ class Album(Basic_object):
             you cannot remove (non-existing, not owned by you or not part of
             album) will not cause exceptions, but fail silently.
         """
-        url = ("https://api.imgur.com/3/album/%s/remove_images" %
-               self._delete_or_id_hash)
+        url = ("https://api.imgur.com/3/album/{0}/"
+               "remove_images".format(self._delete_or_id_hash))
         # NOTE: Returns True and everything seem to be as it should in testing.
         # Seems most likely to be upstream bug.
         params = {'ids': images}
@@ -304,7 +307,8 @@ class Album(Basic_object):
             images that you cannot set (non-existing or not owned by you) will
             not cause exceptions, but fail silently.
         """
-        url = "https://api.imgur.com/3/album/%s/" % self._delete_or_id_hash
+        url = ("https://api.imgur.com/3/album/"
+               "{0}/".format(self._delete_or_id_hash))
         params = {'ids': images}
         return self._imgur._send_request(url, needs_auth=True, params=params,
                                          method="POST")
@@ -321,7 +325,7 @@ class Album(Basic_object):
             this method will return an error. Set this to True to by-pass the
             terms.
         """
-        url = "https://api.imgur.com/3/gallery/%s" % self.id
+        url = "https://api.imgur.com/3/gallery/{0}".format(self.id)
         payload = {'title': title, 'terms': '1' if bypass_terms else '0'}
         self._imgur._send_request(url, needs_auth=True, params=payload,
                                   method='POST')
@@ -348,7 +352,8 @@ class Album(Basic_object):
         :param layout: The way the album is displayed, can be blog, grid,
             horizontal or vertical.
         """
-        url = "https://api.imgur.com/3/album/%s" % self._delete_or_id_hash
+        url = ("https://api.imgur.com/3/album/"
+               "{0}".format(self._delete_or_id_hash))
         is_updated = self._imgur._send_request(url, params=locals(),
                                                method='POST')
         if is_updated:
@@ -398,32 +403,33 @@ class Comment(Basic_object):
     """
     def __init__(self, json_dict, imgur, has_fetched=True):
         self.deletehash = None
-        self._INFO_URL = ("https://api.imgur.com/3/comment/%s" %
-                          json_dict['id'])
+        self._INFO_URL = ("https://api.imgur.com/3/comment/"
+                          "{0}".format(json_dict['id']))
         super(Comment, self).__init__(json_dict, imgur, has_fetched)
 
     def delete(self):
         """Delete the comment."""
-        url = "https://api.imgur.com/3/image/%s" % self._delete_or_id_hash
+        url = ("https://api.imgur.com/3/image/"
+               "{0}".format(self._delete_or_id_hash))
         return self._imgur._send_request(url, method='DELETE')
         # NOTE: Gives a 403 permission denied error on comment 77087313 which
         # made by me.
 
     def downvote(self):
         """Downvote this comment."""
-        url = "https://api.imgur.com/3/comment/%s/vote/down" % self.id
+        url = "https://api.imgur.com/3/comment/{0}/vote/down".format(self.id)
         return self._imgur._send_request(url, needs_auth=True, method='POST')
 
     def get_replies(self):
         """Get the replies to this comment."""
-        url = "https://api.imgur.com/3/comment/%s/replies" % self.id
+        url = "https://api.imgur.com/3/comment/{0}/replies".format(self.id)
         json = self._imgur._send_request(url)
         child_comments = json['children']
         return [Comment(com, self._imgur) for com in child_comments]
 
     def reply(self, text):
         """Make a comment reply."""
-        url = "https://api.imgur.com/3/comment/%s" % self.id
+        url = "https://api.imgur.com/3/comment/{0}".format(self.id)
         payload = {'image_id': self.image.id, 'comment': text}
         resp = self._imgur._send_request(url, params=payload, needs_auth=True,
                                          method='POST')
@@ -440,7 +446,7 @@ class Comment(Basic_object):
 
     def upvote(self):
         """Upvote this comment."""
-        url = "https://api.imgur.com/3/comment/%s/vote/up" % self.id
+        url = "https://api.imgur.com/3/comment/{0}/vote/up".format(self.id)
         return self._imgur._send_request(url, needs_auth=True, method='POST')
 
 
@@ -466,18 +472,18 @@ class Gallery_item(object):
         something the authenticated user has already downvoted will set the
         vote to neutral.
         """
-        url = "https://api.imgur.com/3/gallery/%s/vote/down" % self.id
+        url = "https://api.imgur.com/3/gallery/{0}/vote/down".format(self.id)
         return self._imgur._send_request(url, needs_auth=True, method='POST')
 
     def get_comments(self):
         """Get a list of the top-level comments."""
-        url = "https://api.imgur.com/3/gallery/%s/comments" % self.id
+        url = "https://api.imgur.com/3/gallery/{0}/comments".format(self.id)
         resp = self._imgur._send_request(url)
         return [Comment(com, self._imgur) for com in resp]
 
     def remove_from_gallery(self):
         """Remove this image from the gallery."""
-        url = "https://api.imgur.com/3/gallery/%s" % self.id
+        url = "https://api.imgur.com/3/gallery/{0}".format(self.id)
         self._imgur._send_request(url, needs_auth=True, method='DELETE')
         if isinstance(self, Image):
             item = self._imgur.get_image(self.id)
@@ -494,7 +500,7 @@ class Gallery_item(object):
         something the authenticated user has already upvoted will set the vote
         to neutral.
         """
-        url = "https://api.imgur.com/3/gallery/%s/vote/up" % self.id
+        url = "https://api.imgur.com/3/gallery/{0}/vote/up".format(self.id)
         return self._imgur._send_request(url, needs_auth=True, method='POST')
 
 
@@ -525,15 +531,16 @@ class Image(Basic_object):
     :ivar width: The width of the image in bytes.
     """
     def __init__(self, json_dict, imgur, has_fetched=True):
-        self._INFO_URL = ("https://api.imgur.com/3/image/%s" % json_dict['id'])
+        self._INFO_URL = ("https://api.imgur.com/3/image/"
+                          "{0}".format(json_dict['id']))
         self.deletehash = None
         super(Image, self).__init__(json_dict, imgur, has_fetched)
 
     def delete(self):
         """Delete the image."""
-        return self._imgur._send_request("https://api.imgur.com/3/image/%s" %
-                                         self._delete_or_id_hash,
-                                         method='DELETE')
+        url = ("https://api.imgur.com/3/image/"
+               "{0}".format(self._delete_or_id_hash))
+        return self._imgur._send_request(url, method='DELETE')
 
     def download(self, path='', name=None, overwrite=False, size=None):
         """
@@ -559,8 +566,8 @@ class Image(Basic_object):
         def save_as(filename):
             local_path = os.path.join(path, filename)
             if os.path.exists(local_path) and not overwrite:
-                raise Exception("Trying to save as %s, but file already exists." %
-                                local_path)
+                raise Exception("Trying to save as {0}, but file "
+                                "already exists.".format(local_path))
             with open(local_path, 'wb') as out_file:
                 out_file.write(resp.content)
             return local_path
@@ -570,8 +577,8 @@ class Image(Basic_object):
         if size is not None:
             size = size.lower().replace(' ', '_')
             if size not in valid_sizes:
-                raise LookupError('Invalid size. Valid options are: %s' % ", "
-                                  .join(valid_sizes.keys()))
+                raise LookupError('Invalid size. Valid options are: {0}'.format(
+                                  ", " .join(valid_sizes.keys())))
         suffix = valid_sizes.get(size, '')
         base, sep, ext = self.link.rpartition('.')
         resp = requests.get(base + suffix + sep + ext)
@@ -589,7 +596,7 @@ class Image(Basic_object):
 
         Favoriting an already favorited image will unfavorite it.
         """
-        url = "https://api.imgur.com/3/image/%s/favorite" % self.id
+        url = "https://api.imgur.com/3/image/{0}/favorite".format(self.id)
         return self._imgur._send_request(url, needs_auth=True, method='POST')
 
     def submit_to_gallery(self, title, bypass_terms=False):
@@ -604,7 +611,7 @@ class Image(Basic_object):
             this method will return an error. Set this to True to by-pass the
             terms.
         """
-        url = "https://api.imgur.com/3/gallery/%s" % self.id
+        url = "https://api.imgur.com/3/gallery/{0}".format(self.id)
         payload = {'title': title, 'terms': '1' if bypass_terms else '0'}
         self._imgur._send_request(url, needs_auth=True, params=payload,
                                   method='POST')
@@ -614,7 +621,8 @@ class Image(Basic_object):
 
     def update(self, title=None, description=None):
         """Update the image with a new title and/or description."""
-        url = "https://api.imgur.com/3/image/%s" % self._delete_or_id_hash
+        url = ("https://api.imgur.com/3/image/"
+               "{0}".format(self._delete_or_id_hash))
         is_updated = self._imgur._send_request(url, params=locals(),
                                                method='POST')
         if is_updated:
@@ -632,7 +640,7 @@ class Imgur:
     but instead use the methods in this class to get them.
     """
     def __init__(self, client_id, client_secret=None, access_token=None,
-                 refresh_token=None):
+                 refresh_token=None, verify=True):
         """
         Initialize the Imgur object.
 
@@ -651,6 +659,8 @@ class Imgur:
             access_tokens expire after 1 hour, we need a way to request new
             ones without going through the entire authorization step again. It
             does not expire.
+        :param verify: Verify SSL certificate of server
+            (can result in SSLErrors)?
         """
         self.is_authenticated = False
         self.access_token = access_token
@@ -663,6 +673,7 @@ class Imgur:
         self.ratelimit_userremaining = None
         self.ratelimit_userreset = None
         self.refresh_token = refresh_token
+        self.verify = verify
 
     def _send_request(self, url, needs_auth=False, **kwargs):
         """
@@ -687,9 +698,9 @@ class Imgur:
                             "method.")
         if self.access_token is None:
             # Not authenticated as a user. Use anonymous access.
-            auth = {'Authorization': 'Client-ID %s' % self.client_id}
+            auth = {'Authorization': 'Client-ID {0}'.format(self.client_id)}
         else:
-            auth = {'Authorization': 'Bearer %s' % self.access_token}
+            auth = {'Authorization': 'Bearer {0}'.format(self.access_token)}
         content = []
         is_paginated = False
         if 'limit' in kwargs:
@@ -698,15 +709,15 @@ class Imgur:
             del kwargs['limit']
             page = 0
             base_url = url
-            url %= page
+            url.format(page)
         kwargs['authentication'] = auth
         while True:
-            result = request.send_request(url, **kwargs)
+            result = request.send_request(url, verify=self.verify, **kwargs)
             new_content, ratelimit_info = result
             if is_paginated and new_content and limit > len(new_content):
                 content += new_content
                 page += 1
-                url = base_url % page
+                url = base_url.format(page)
             else:
                 if is_paginated:
                     content = (content + new_content)[:limit]
@@ -738,7 +749,7 @@ class Imgur:
             correct resource in your site, nonces, and
             cross-site-request-forgery mitigations.
         """
-        return AUTHORIZE_URL % (self.client_id, response, state)
+        return AUTHORIZE_URL.format(self.client_id, response, state)
 
     def change_authentication(self, client_id=None, client_secret=None,
                               access_token=None, refresh_token=None):
@@ -788,7 +799,7 @@ class Imgur:
         params = {'client_id': self.client_id,
                   'client_secret': self.client_secret,
                   'grant_type': 'authorization_code',
-                  'pin': code}
+                  'code': code}
         result = self._send_request(EXCHANGE_URL, params=params, method='POST',
                                     data_field=None)
         self.access_token = result['access_token']
@@ -809,7 +820,8 @@ class Imgur:
 
     def get_album(self, id):
         """Return information about this album."""
-        json = self._send_request("https://api.imgur.com/3/album/%s" % id)
+        url = "https://api.imgur.com/3/album/{0}".format(id)
+        json = self._send_request(url)
         return Album(json, self)
 
     def get_at_url(self, url):
@@ -820,6 +832,15 @@ class Imgur:
 
         Works for Album, Comment, Gallery_album, Gallery_image, Image and User.
 
+        NOTE: Imgur's documentation does not cover what urls are available.
+        Some urls, such as imgur.com/<ID> can be for several different types of
+        object. Using a wrong, but similair call, such as get_subreddit_image
+        on a meme image will not cause an error. But instead return a subset of
+        information, with either the remaining pieces missing or the value set
+        to None. This makes it hard to create a method such as this that
+        attempts to deduce the object from the url. Due to these factors, this
+        method should be considered experimental and used carefully.
+
         :param url: The url where the content is located at
         """
         class NullDevice():
@@ -858,7 +879,10 @@ class Imgur:
                 return self.get_gallery_album(id)
             finally:
                 sys.stdout = original_stdout  # turn STDOUT back on
-        base = "(https?://)(i\\.)?imgur.com/"
+
+        if not self.is_imgur_url(url):
+            return None
+
         objects = {'album': {'regex': "a/(?P<id>[\w.]*?)$",
                              'method': self.get_album},
                    'comment': {'regex': "gallery/\w*/comment/(?P<id>[\w.]*?)$",
@@ -872,8 +896,9 @@ class Imgur:
                    'user': {'regex': "user/(?P<id>[\w.]*?)$",
                             'method': self.get_user}
                    }
+        parsed_url = urlparse(url)
         for obj_type, values in objects.items():
-            regex_result = re.match(base + values['regex'], url)
+            regex_result = re.match('/' + values['regex'], parsed_url.path)
             if regex_result is not None:
                 obj_id = regex_result.group('id')
                 initial_object = values['method'](obj_id)
@@ -897,7 +922,7 @@ class Imgur:
 
     def get_comment(self, id):
         """Return information about this comment."""
-        url = "https://api.imgur.com/3/comment/%s" % id
+        url = "https://api.imgur.com/3/comment/{0}".format(id)
         json = self._send_request(url)
         return Comment(json, self)
 
@@ -914,8 +939,8 @@ class Imgur:
             'user' section. Defaults to true.
         :param limit: The number of items to return.
         """
-        url = ("https://api.imgur.com/3/gallery/%s/%s/%s/%s?showViral=%s" %
-               (section, sort, window, '%d', show_viral))
+        url = ("https://api.imgur.com/3/gallery/{}/{}/{}/{}?showViral="
+               "{}".format(section, sort, window, '{}', show_viral))
         resp = self._send_request(url, limit=limit)
         return [_get_album_or_image(thing, self) for thing in resp]
 
@@ -927,7 +952,7 @@ class Imgur:
         This makes it possible to remove an album from the gallery and setting
         it's privacy setting as secret, without compromising it's secrecy.
         """
-        url = "https://api.imgur.com/3/gallery/album/%s" % id
+        url = "https://api.imgur.com/3/gallery/album/{0}".format(id)
         resp = self._send_request(url)
         return Gallery_album(resp, self)
 
@@ -939,13 +964,14 @@ class Imgur:
         This makes it possible to remove an image from the gallery and setting
         it's privacy setting as secret, without compromising it's secrecy.
         """
-        url = "https://api.imgur.com/3/gallery/image/%s" % id
+        url = "https://api.imgur.com/3/gallery/image/{0}".format(id)
         resp = self._send_request(url)
         return Gallery_image(resp, self)
 
     def get_image(self, id):
         """Return a Image object representing the image with the given id."""
-        resp = self._send_request("https://api.imgur.com/3/image/%s" % id)
+        url = "https://api.imgur.com/3/image/{0}".format(id)
+        resp = self._send_request(url)
         return Image(resp, self)
 
     def get_message(self, id):
@@ -954,7 +980,8 @@ class Imgur:
 
         :param id: The id of the message object to return.
         """
-        resp = self._send_request("https://api.imgur.com/3/message/%s" % id)
+        url = "https://api.imgur.com/3/message/{0}".format(id)
+        resp = self._send_request(url)
         return Message(resp, self)
 
     def get_notification(self, id):
@@ -963,8 +990,8 @@ class Imgur:
 
         :param id: The id of the notification object to return.
         """
-        resp = self._send_request("https://api.imgur.com/3/notification/%s" %
-                                  id)
+        url = "https://api.imgur.com/3/notification/{0}".format(id)
+        resp = self._send_request(url)
         return Notification(resp, self)
 
     def get_memes_gallery(self, sort='viral', window='week', limit=None):
@@ -978,8 +1005,8 @@ class Imgur:
             "top", day | week | month | year | all, defaults to week.
         :param limit: The number of items to return.
         """
-        url = ("https://api.imgur.com/3/gallery/g/memes/%s/%s/%s" %
-               (sort, window, '%d'))
+        url = ("https://api.imgur.com/3/gallery/g/memes/{0}/{1}/{2}".format(
+               sort, window, '{}'))
         resp = self._send_request(url, limit=limit)
         return [_get_album_or_image(thing, self) for thing in resp]
 
@@ -1014,8 +1041,8 @@ class Imgur:
             "top", day | week | month | year | all, defaults to day.
         :param limit: The number of items to return.
         """
-        url = ("https://api.imgur.com/3/gallery/r/%s/%s}/%s/%s" %
-               (subreddit, sort, window, '%d'))
+        url = ("https://api.imgur.com/3/gallery/r/{0}/{1}/{2}/{3}".format(
+               subreddit, sort, window, '{}'))
         resp = self._send_request(url, limit=limit)
         return [_get_album_or_image(thing, self) for thing in resp]
 
@@ -1026,7 +1053,7 @@ class Imgur:
         :param subreddit: The subreddit the image has been submitted to.
         :param id: The id of the image we want.
         """
-        url = "https://api.imgur.com/3/gallery/r/%s/%s" % (subreddit, id)
+        url = "https://api.imgur.com/3/gallery/r/{0}/{1}".format(subreddit, id)
         resp = self._send_request(url)
         return Gallery_image(resp, self)
 
@@ -1036,7 +1063,7 @@ class Imgur:
 
         :param username: The name of the user we want more information about.
         """
-        url = "https://api.imgur.com/3/account/%s" % username
+        url = "https://api.imgur.com/3/account/{0}".format(username)
         json = self._send_request(url)
         return User(json, self)
 
@@ -1068,7 +1095,7 @@ class Imgur:
 
     def search_gallery(self, q):
         """Search the gallery with the given query string."""
-        url = "https://api.imgur.com/3/gallery/search?q=%s" % q
+        url = "https://api.imgur.com/3/gallery/search?q={0}".format(q)
         resp = self._send_request(url)
         return [_get_album_or_image(thing, self) for thing in resp]
 
@@ -1119,8 +1146,8 @@ class Imgur:
 class Message(Basic_object):
     """This corresponds to the messages users can send each other."""
     def __init__(self, json_dict, imgur, has_fetched=True):
-        self._INFO_URL = ("https://api.imgur.com/3/message/%s" %
-                          json_dict['id'])
+        self._INFO_URL = ("https://api.imgur.com/3/message/{0}".format(
+                          json_dict['id']))
         super(Message, self).__init__(json_dict, imgur, has_fetched)
 
     '''
@@ -1135,13 +1162,13 @@ class Message(Basic_object):
 
     def delete(self):
         """Delete the message."""
-        url = "https://api.imgur.com/3/message/%s" % self.id
+        url = "https://api.imgur.com/3/message/{0}".format(self.id)
         return self._imgur._send_request(url, method='DELETE')
 
     def get_thread(self):
         """Return the message thread this Message is in."""
-        url = ("https://api.imgur.com/3/message/%s/thread" %
-               self.first_message.id)
+        url = ("https://api.imgur.com/3/message/{0}/thread".format(
+               self.first_message.id))
         resp = self._imgur._send_request(url)
         return [Message(msg, self._imgur) for msg in resp]
 
@@ -1182,8 +1209,8 @@ class Notification(Basic_object):
     """
     def __init__(self, json_dict, imgur, has_fetched=True):
         # Is never gotten lazily, so _has_fetched is always True
-        self._INFO_URL = ("https://api.imgur.com/3/notification/%s" %
-                          json_dict['id'])
+        self._INFO_URL = ("https://api.imgur.com/3/notification/{0}".format(
+                          json_dict['id']))
         super(Notification, self).__init__(json_dict, imgur, has_fetched)
 
     def mark_as_viewed(self):
@@ -1192,7 +1219,7 @@ class Notification(Basic_object):
 
         Notifications cannot be marked as unviewed.
         """
-        url = "https://api.imgur.com/3/notification/%s" % self.id
+        url = "https://api.imgur.com/3/notification/{0}".format(self.id)
         return self._imgur._send_request(url, method='POST')
 
 
@@ -1208,13 +1235,13 @@ class User(Basic_object):
     :ivar reputation: Total likes - dislikes of the user's created content.
     """
     def __init__(self, json_dict, imgur, has_fetched=True):
-        self._INFO_URL = ("https://api.imgur.com/3/account/%s" %
-                          json_dict['url'])
+        self._INFO_URL = ("https://api.imgur.com/3/account/{0}".format(
+                          json_dict['url']))
         super(User, self).__init__(json_dict, imgur, has_fetched)
 
     # Overrides __repr__ method in Basic_object
     def __repr__(self):
-        return "<%s %s>" % (type(self).__name__, self.name)
+        return "<{0} {1}>".format(type(self).__name__, self.name)
 
     def change_settings(self, bio=None, public_images=None,
                         messaging_enabled=None, album_privacy=None,
@@ -1235,14 +1262,14 @@ class User(Basic_object):
         # NOTE: album_privacy should maybe be renamed to default_privacy
         # NOTE: public_images is a boolean, despite the documentation saying it
         # is a string.
-        url = "https://api.imgur.com/3/account/%s/settings" % self.name
+        url = "https://api.imgur.com/3/account/{0}/settings".format(self.name)
         resp = self._imgur._send_request(url, needs_auth=True, params=locals(),
                                          method='POST')
         return resp
 
     def delete(self):
         """Delete this user. Require being authenticated as the user."""
-        url = "https://api.imgur.com/3/account/%s" % self.name
+        url = "https://api.imgur.com/3/account/{0}".format(self.name)
         return self._imgur._send_request(url, needs_auth=True, method='DELETE')
 
     def get_albums(self, limit=None):
@@ -1252,33 +1279,34 @@ class User(Basic_object):
         Secret and hidden albums are only returned if this is the logged-in
         user.
         """
-        url = "https://api.imgur.com/3/account/%s/albums/%s" % (self.name,
-                                                                '%d')
+        url = ("https://api.imgur.com/3/account/{0}/albums/{1}".format(self.name,
+                                                                       '{}'))
         resp = self._imgur._send_request(url, limit=limit)
         return [Album(alb, self._imgur, False) for alb in resp]
 
     def get_comments(self):
         """Return the comments made by the user."""
-        url = "https://api.imgur.com/3/account/%s/comments" % self.name
+        url = "https://api.imgur.com/3/account/{0}/comments".format(self.name)
         resp = self._imgur._send_request(url)
         return [Comment(com, self._imgur) for com in resp]
 
     def get_favorites(self):
         """Return the users favorited images."""
-        url = "https://api.imgur.com/3/account/%s/favorites" % self.name
+        url = "https://api.imgur.com/3/account/{0}/favorites".format(self.name)
         resp = self._imgur._send_request(url, needs_auth=True)
         return [_get_album_or_image(thing, self) for thing in resp]
 
     def get_gallery_favorites(self):
         """Get a list of the images in the gallery this user has favorited."""
-        url = ("https://api.imgur.com/3/account/%s/gallery_favorites" %
-               self.name)
+        url = ("https://api.imgur.com/3/account/{0}/gallery_favorites".format(
+               self.name))
         resp = self._imgur._send_request(url)
         return [Image(img, self._imgur) for img in resp]
 
     def get_gallery_profile(self):
         """Return the users gallery profile."""
-        url = "https://api.imgur.com/3/account/%s/gallery_profile" % self.name
+        url = ("https://api.imgur.com/3/account/{0}/"
+               "gallery_profile".format(self.name))
         return self._imgur._send_request(url)
 
     def has_verified_email(self):
@@ -1289,13 +1317,14 @@ class User(Basic_object):
         sending an email to the user and the owner of the email user verifying
         that he is the same as the Imgur user.
         """
-        url = "https://api.imgur.com/3/account/%s/verifyemail" % self.name
+        url = ("https://api.imgur.com/3/account/{0}/"
+               "verifyemail".format(self.name))
         return self._imgur._send_request(url, needs_auth=True)
 
     def get_images(self, limit=None):
         """Return all of the images associated with the user."""
-        url = "https://api.imgur.com/3/account/%s/images/%s" % (self.name,
-                                                                '%d')
+        url = ("https://api.imgur.com/3/account/{0}/"
+               "images/{1}".format(self.name, '{}'))
         resp = self._imgur._send_request(url, limit=limit)
         return [Image(img, self._imgur) for img in resp]
 
@@ -1306,8 +1335,8 @@ class User(Basic_object):
         :param new: False for all notifications, True for only non-viewed
             notifications.
         """
-        url = ("https://api.imgur.com/3/account/%s/notifications/messages" %
-               self.name)
+        url = ("https://api.imgur.com/3/account/{0}/notifications/"
+               "messages".format(self.name))
         result = self._imgur._send_request(url, params=locals(),
                                            needs_auth=True)
         return [Notification(msg_dict, self._imgur, has_fetched=True) for
@@ -1315,12 +1344,13 @@ class User(Basic_object):
 
     def get_notifications(self, new=True):
         """Return all the notifications for this user."""
-        url = "https://api.imgur.com/3/account/%s/notifications" % self.name
+        url = ("https://api.imgur.com/3/account/{0}/"
+               "notifications".format(self.name))
         resp = self._imgur._send_request(url, params=locals(), needs_auth=True)
-        msgs = [Message(msg_dict, self._imgur, has_fetched=True) for msg_dict in
-                resp['messages']]
-        replies = [Comment(msg_dict, self._imgur, has_fetched=True) for com_dict
-                   in resp['replies']]
+        msgs = [Message(msg_dict, self._imgur, has_fetched=True) for msg_dict
+                in resp['messages']]
+        replies = [Comment(msg_dict, self._imgur, has_fetched=True) for
+                   com_dict in resp['replies']]
         return {'messages': msgs, 'replies': replies}
 
     def get_replies(self, new=True):
@@ -1330,8 +1360,8 @@ class User(Basic_object):
         :param new: False for all notifications, True for only non-viewed
             notifications.
         """
-        url = ("https://api.imgur.com/3/account/%s/notifications/replies" %
-               self.name)
+        url = ("https://api.imgur.com/3/account/{0}/"
+               "notifications/replies".format(self.name))
         return self._imgur._send_request(url, needs_auth=True)
 
     def get_settings(self):
@@ -1340,18 +1370,18 @@ class User(Basic_object):
 
         Only accessible if authenticated as the user.
         """
-        url = "https://api.imgur.com/3/account/%s/settings" % self.name
+        url = "https://api.imgur.com/3/account/{0}/settings".format(self.name)
         return self._imgur._send_request(url)
 
     def get_statistics(self):
         """Return statistics about this user."""
-        url = "https://api.imgur.com/3/account/%s/stats" % self.name
+        url = "https://api.imgur.com/3/account/{0}/stats".format(self.name)
         return self._imgur._send_request(url, needs_auth=True)
 
     def get_submissions(self, limit=None):
         """Return a list of the images a user has submitted to the gallery."""
-        url = "https://api.imgur.com/3/account/%s/submissions/%s" % (self.name,
-                                                                     '%d')
+        url = ("https://api.imgur.com/3/account/{0}/submissions/"
+               "{1}".format(self.name, '{}'))
         resp = self._imgur._send_request(url, limit=limit)
         return [_get_album_or_image(thing, self._imgur) for thing in resp]
 
@@ -1382,7 +1412,8 @@ class User(Basic_object):
         Remember that the verification email may end up in the users spam
         folder.
         """
-        url = "https://api.imgur.com/3/account/%s/verifyemail" % self.name
+        url = ("https://api.imgur.com/3/account/{0}"
+               "/verifyemail".format(self.name))
         self._imgur._send_request(url, needs_auth=True, method='POST')
 
 
@@ -1391,15 +1422,15 @@ class User(Basic_object):
 # alphabetically without errors.
 class Gallery_album(Album, Gallery_item):
     """Gallery Albums are albums submitted to the gallery."""
-    def __init__(self, json_dict, imgur):
-        self._INFO_URL = ("https://api.imgur.com/3/gallery/album/%s" %
-                          json_dict['id'])
-        super(Gallery_album, self).__init__(json_dict, imgur)
+    def __init__(self, json_dict, imgur, has_fetched=True):
+        self._INFO_URL = ("https://api.imgur.com/3/gallery/album/"
+                          "{0}".format(json_dict['id']))
+        super(Gallery_album, self).__init__(json_dict, imgur, has_fetched)
 
 
 class Gallery_image(Image, Gallery_item):
     """Gallery images are images submitted to the gallery."""
-    def __init__(self, json_dict, imgur):
-        self._INFO_URL = ("http://api.imgur.com/3/gallery/image/%s" %
-                          json_dict['id'])
-        super(Gallery_image, self).__init__(json_dict, imgur)
+    def __init__(self, json_dict, imgur, has_fetched=True):
+        self._INFO_URL = ("http://api.imgur.com/3/gallery/image/"
+                          "{0}".format(json_dict['id']))
+        super(Gallery_image, self).__init__(json_dict, imgur, has_fetched)
